/opt/jdk1.6.0_16/bin/jmap -heap `ps -ef |grep java|grep start|cut -c10-15`
output:
Heap Configuration:
MinHeapFreeRatio = 40
MaxHeapFreeRatio = 70
MaxHeapSize = 1073741824 (1024.0MB)
NewSize = 1048576 (1.0MB)
MaxNewSize = 4294901760 (4095.9375MB)
OldSize = 4194304 (4.0MB)
NewRatio = 8
SurvivorRatio = 8
PermSize = 16777216 (16.0MB)
MaxPermSize = 67108864 (64.0MB)
Heap Usage:
PS Young Generation
Eden Space:
capacity = 103219200 (98.4375MB)
used = 31150464 (29.7073974609375MB)
free = 72068736 (68.7301025390625MB)
30.178943452380953% used
From Space:
capacity = 7864320 (7.5MB)
used = 3225432 (3.0760116577148438MB)
free = 4638888 (4.423988342285156MB)
41.01348876953125% used
To Space:
capacity = 7471104 (7.125MB)
used = 0 (0.0MB)
free = 7471104 (7.125MB)
0.0% used
PS Old Generation
capacity = 954466304 (910.25MB)
used = 793981280 (757.1995544433594MB)
free = 160485024 (153.05044555664062MB)
83.18588898031962% used
PS Perm Generation
capacity = 23461888 (22.375MB)
used = 23309160 (22.229347229003906MB)
free = 152728 (0.14565277099609375MB)
99.34903789498952% used
Thursday, August 16, 2012
Bash Scripting tutorial
1. Hello World Bash Shell Script
First you need to find out where is your bash interpreter located. Enter the following into your command line:
$ which bash
Open up you favorite text editor and a create file called hello_world.sh. Insert the following lines to a file:
NOTE:Every bash shell script in this tutorial starts with shebang:"#!" which is not read as a comment. First line is also a place where you put your interpreter which is in this case: /bin/bash.
Here is our first bash shell script example:
#!/bin/bash # declare STRING variable STRING="Hello World" #print variable on a screen echo $STRING
Navigate to a directory where your hello_world.sh is located and make the file executable:
$ chmod +x hello_world.sh
Now you are ready to execute your first bash script:
./hello_world.sh
2. Simple Backup bash shell script
#!/bin/bash tar -czf myhome_directory.tar.gz /home/linuxconfig
3. Variables
In this example we declare simple bash variable and print it on the screen ( stdout ) with echo command.
#!/bin/bash STRING="HELLO WORLD!!!" echo $STRING
Your backup script and variables:
#!/bin/bash OF=myhome_directory_$(date +%Y%m%d).tar.gz tar -czf $OF /home/linuxconfig
3.1. Global vs. Local variables
#!/bin/bash
#Define bash global variable
#This variable is global and can be used anywhere in this bash script
VAR="global variable"
function bash {
#Define bash local variable
#This variable is local to bash function only
local VAR="local variable"
echo $VAR
}
echo $VAR
bash
# Note the bash global variable did not change
# "local" is bash reserved word
echo $VAR
4. Passing arguments to the bash script
#!/bin/bash
# use predefined variables to access passed arguments
#echo arguments to the shell
echo $1 $2 $3 ' -> echo $1 $2 $3'
# We can also store arguments from bash command line in special array
args=("$@")
#echo arguments to the shell
echo ${args[0]} ${args[1]} ${args[2]} ' -> args=("$@"); echo ${args[0]} ${args[1]} ${args[2]}'
#use $@ to print out all arguments at once
echo $@ ' -> echo $@'
# use $# variable to print out
# number of arguments passed to the bash script
echo Number of arguments passed: $# ' -> echo Number of arguments passed: $#'
/arguments.sh Bash Scripting Tutorial
5. Executing shell commands with bash
#!/bin/bash # use backticks " ` ` " to execute shell command echo `uname -o` # executing bash command without backticks echo uname -o
6. Reading User Input
#!/bin/bash
echo -e "Hi, please type the word: \c "
read word
echo "The word you entered is: $word"
echo -e "Can you please enter two words? "
read word1 word2
echo "Here is your input: \"$word1\" \"$word2\""
echo -e "How do you feel about bash scripting? "
# read command now stores a reply into the default build-in variable $REPLY
read
echo "You said $REPLY, I'm glad to hear that! "
echo -e "What are your favorite colours ? "
# -a makes read command to read into an array
read -a colours
echo "My favorite colours are also ${colours[0]}, ${colours[1]} and ${colours[2]}:-)"
7. Bash Trap Command
#!/bin/bash
# bash trap command
trap bashtrap INT
# bash clear screen command
clear;
# bash trap function is executed when CTRL-C is pressed:
# bash prints message => Executing bash trap subrutine !
bashtrap()
{
echo "CTRL+C Detected !...executing bash trap !"
}
# for loop from 1/10 to 10/10
for a in `seq 1 10`; do
echo "$a/10 to Exit."
sleep 1;
done
echo "Exit Bash Trap Example!!!"
|
8. Arrays
8.1. Declare simple bash array
#!/bin/bash
#Declare array with 4 elements
ARRAY=( 'Debian Linux' 'Redhat Linux' Ubuntu Linux )
# get number of elements in the array
ELEMENTS=${#ARRAY[@]}
# echo each element in array
# for loop
for (( i=0;i<$ELEMENTS;i++)); do
echo ${ARRAY[$]}
done
8.2. Read file into bash array
#!/bin/bash
# Declare array
declare -a ARRAY
# Link filedescriptor 10 with stdin
exec 10<&0
# stdin replaced with a file supplied as a first argument
exec < $1
let count=0
while read LINE; do
ARRAY[$count]=$LINE
((count++))
done
echo Number of elements: ${#ARRAY[@]}
# echo array's content
echo ${ARRAY[@]}
# restore stdin from filedescriptor 10
# and close filedescriptor 10
exec 0<&10 10<&-
9. Bash if / else / fi statements
9.1. Simple Bash if/else statement
Please note the spacing inside the [ and ] brackets! Without the spaces, it won't work!
#!/bin/bash directory="./BashScripting" # bash check if directory exists if [ -d $directory ]; then echo "Directory exists" else echo "Directory does not exists" fi
9.2. Nested if/else
#!/bin/bash
# Declare variable choice and assign value 4
choice=4
# Print to stdout
echo "1. Bash"
echo "2. Scripting"
echo "3. Tutorial"
echo -n "Please choose a word [1,2 or 3]? "
# Loop while the variable choice is equal 4
# bash while loop
while [ $choice -eq 4 ]; do
# read user input
read choice
# bash nested if/else
if [ $choice -eq 1 ] ; then
echo "You have chosen word: Bash"
else
if [ $choice -eq 2 ] ; then
echo "You have chosen word: Scripting"
else
if [ $choice -eq 3 ] ; then
echo "You have chosen word: Tutorial"
else
echo "Please make a choice between 1-3 !"
echo "1. Bash"
echo "2. Scripting"
echo "3. Tutorial"
echo -n "Please choose a word [1,2 or 3]? "
choice=4
fi
fi
fi
done
10. Bash Comparisons
10.1. Arithmetic Comparisons
| -lt | < |
| -gt | > |
| -le | <= |
| -ge | >= |
| -eq | == |
| -ne | != |
#!/bin/bash # declare integers NUM1=2 NUM2=2 if [ $NUM1 -eq $NUM2 ]; then echo "Both Values are equal" else echo "Values are NOT equal" fi
#!/bin/bash # declare integers NUM1=2 NUM2=1 if [ $NUM1 -eq $NUM2 ]; then echo "Both Values are equal" else echo "Values are NOT equal" fi
#!/bin/bash # declare integers NUM1=2 NUM2=1 if [ $NUM1 -eq $NUM2 ]; then echo "Both Values are equal" elif [ $NUM1 -gt $NUM2 ]; then echo "NUM1 is greater then NUM2" else echo "NUM2 is greater then NUM1" fi
10.2. String Comparisons
| = | equal |
| != | not equal |
| < | less then |
| > | greater then |
| -n s1 | string s1 is not empty |
| -z s1 | string s1 is empty |
#!/bin/bash #Declare string S1 S1="Bash" #Declare string S2 S2="Scripting" if [ $S1 = $S2 ]; then echo "Both Strings are equal" else echo "Strings are NOT equal" fi
#!/bin/bash #Declare string S1 S1="Bash" #Declare string S2 S2="Bash" if [ $S1 = $S2 ]; then echo "Both Strings are equal" else echo "Strings are NOT equal" fi
11. Bash File Testing
| -b filename | Block special file |
| -c filename | Special character file |
| -d directoryname | Check for directory existence |
| -e filename | Check for file existence |
| -f filename | Check for regular file existence not a directory |
| -G filename | Check if file exists and is owned by effective group ID. |
| -g filename | true if file exists and is set-group-id. |
| -k filename | Sticky bit |
| -L filename | Symbolic link |
| -O filename | True if file exists and is owned by the effective user id. |
| -r filename | Check if file is a readable |
| -S filename | Check if file is socket |
| -s filename | Check if file is nonzero size |
| -u filename | Check if file set-ser-id bit is set |
| -w filename | Check if file is writable |
| -x filename | Check if file is executable |
#!/bin/bash file="./file" if [ -e $file ]; then echo "File exists" else echo "File does not exists" fi
Similarly for example we can use while loop to check if file does not exists. This script will sleep until file does exists. Note bash negator "!" which negates the -e option.
#!/bin/bash while [ ! -e myfile ]; do # Sleep until file does exists/is created sleep 1 done
12. Loops
12.1. Bash for loop
#!/bin/bash # bash for loop for f in $( ls /var/ ); do echo $f done
Running for loop from bash shell command line:
$ for f in $( ls /var/ ); do echo $f; done
12.2. Bash while loop
#!/bin/bash COUNT=6 # bash while loop while [ $COUNT -gt 0 ]; do echo Value of count is: $COUNT let COUNT=COUNT-1 done
12.3. Bash until loop
#!/bin/bash
COUNT=0
# bash until loop
until [ $COUNT -gt 5 ]; do
echo Value of count is: $COUNT
let COUNT=COUNT+1
done
12.4. Control bash loop with
Here is a example of while loop controlled by standard input. Until the redirection chain from STDOUT to STDIN to the read command exists the while loop continues.
#!/bin/bash # This bash script will locate and replace spaces # in the filenames DIR="." # Controlling a loop with bash read command by redirecting STDOUT as # a STDIN to while loop # find will not truncate filenames containing spaces find $DIR -type f | while read file; do # using POSIX class [:space:] to find space in the filename if [[ "$file" = *[[:space:]]* ]]; then # substitute space with "_" character and consequently rename the file mv "$file" `echo $file | tr ' ' '_'` fi; # end of while loop done
13. Bash Functions
!/bin/bash
# BASH FUNCTIONS CAN BE DECLARED IN ANY ORDER
function function_B {
echo Function B.
}
function function_A {
echo $1
}
function function_D {
echo Function D.
}
function function_C {
echo $1
}
# FUNCTION CALLS
# Pass parameter to function A
function_A "Function A."
function_B
# Pass parameter to function C
function_C "Function C."
function_D
14. Bash Select
#!/bin/bash PS3='Choose one word: ' # bash select select word in "linux" "bash" "scripting" "tutorial" do echo "The word you have selected is: $word" # Break, otherwise endless loop break done exit 0
15. Case statement conditional
#!/bin/bash
echo "What is your preferred programming / scripting language"
echo "1) bash"
echo "2) perl"
echo "3) phyton"
echo "4) c++"
echo "5) I do not know !"
read case;
#simple case bash structure
# note in this case $case is variable and does not have to
# be named case this is just an example
case $case in
1) echo "You selected bash";;
2) echo "You selected perl";;
3) echo "You selected phyton";;
4) echo "You selected c++";;
5) exit
esac
16. Bash quotes and quotations
Quotations and quotes are important part of bash and bash scripting. Here are some bash quotes and quotations basics.
16.1. Escaping Meta characters
Before we start with quotes and quotations we should know something about escaping meta characters. Escaping will suppress a special meaning of meta characters and therefore meta characters will be read by bash literally. To do this we need to use backslash "\" character. Example:
#!/bin/bash #Declare bash string variable BASH_VAR="Bash Script" # echo variable BASH_VAR echo $BASH_VAR #when meta character such us "$" is escaped with "\" it will be read literally echo \$BASH_VAR # backslash has also special meaning and it can be suppressed with yet another "\" echo "\\"
16.2. Single quotes
Single quotes in bash will suppress special meaning of every meta characters. Therefore meta characters will be read literally. It is not possible to use another single quote within two single quotes not even if the single quote is escaped by backslash.
#!/bin/bash #Declare bash string variable BASH_VAR="Bash Script" # echo variable BASH_VAR echo $BASH_VAR # meta characters special meaning in bash is suppressed when using single quotes echo '$BASH_VAR "$BASH_VAR"'
16.3. Double Quotes
Double quotes in bash will suppress special meaning of every meta characters except "$", "\" and "`". Any other meta characters will be read literally. It is also possible to use single quote within double quotes. If we need to use double quotes within double quotes bash can read them literally when escaping them with "\". Example:
#!/bin/bash #Declare bash string variable BASH_VAR="Bash Script" # echo variable BASH_VAR echo $BASH_VAR # meta characters and its special meaning in bash is # suppressed when using double quotes except "$", "\" and "`" echo "It's $BASH_VAR and \"$BASH_VAR\" using backticks: `date`"
16.4. Bash quoting with ANSI-C style
There is also another type of quoting and that is ANSI-C. In this type of quoting characters escaped with "\" will gain special meaning according to the ANSI-C standard.
| \a | alert (bell) | \b | backspace |
| \e | an escape character | \f | form feed |
| \n | newline | \r | carriage return |
| \t | horizontal tab | \v | vertical tab |
| \\ | backslash | \` | single quote |
| \nnn | octal value of characters ( see [http://www.asciitable.com/ ASCII table] ) | \xnn | hexadecimal value of characters ( see [http://www.asciitable.com/ ASCII table] ) |
The syntax fo ansi-c bash quoting is: $'' . Here is an example:
#!/bin/bash # as a example we have used \n as a new line, \x40 is hex value for @ # and \56 is octal value for . echo $'web: www.linuxconfig.org\nemail: web\x40linuxconfig\56org'
17. Arithmetic Operations
17.1. Bash Addition Calculator Example
#!/bin/bash let RESULT1=$1+$2 echo $1+$2=$RESULT1 ' -> # let RESULT1=$1+$2' declare -i RESULT2 RESULT2=$1+$2 echo $1+$2=$RESULT2 ' -> # declare -i RESULT2; RESULT2=$1+$2' echo $1+$2=$(($1 + $2)) ' -> # $(($1 + $2))'
17.2. Bash Arithmetics
#!/bin/bash echo '### let ###' # bash addition let ADDITION=3+5 echo "3 + 5 =" $ADDITION # bash subtraction let SUBTRACTION=7-8 echo "7 - 8 =" $SUBTRACTION # bash multiplication let MULTIPLICATION=5*8 echo "5 * 8 =" $MULTIPLICATION # bash division let DIVISION=4/2 echo "4 / 2 =" $DIVISION # bash modulus let MODULUS=9%4 echo "9 % 4 =" $MODULUS # bash power of two let POWEROFTWO=2**2 echo "2 ^ 2 =" $POWEROFTWO echo '### Bash Arithmetic Expansion ###' # There are two formats for arithmetic expansion: $[ expression ] # and $(( expression #)) its your choice which you use echo 4 + 5 = $((4 + 5)) echo 7 - 7 = $[ 7 - 7 ] echo 4 x 6 = $((3 * 2)) echo 6 / 3 = $((6 / 3)) echo 8 % 7 = $((8 % 7)) echo 2 ^ 8 = $[ 2 ** 8 ] echo '### Declare ###' echo -e "Please enter two numbers \c" # read user input read num1 num2 declare -i result result=$num1+$num2 echo "Result is:$result " # bash convert binary number 10001 result=2#10001 echo $result # bash convert octal number 16 result=8#16 echo $result # bash convert hex number 0xE6A result=16#E6A echo $result
17.3. Round floating point number
#!/bin/bash # get floating point number floating_point_number=3.3446 echo $floating_point_number # round floating point number with bash for bash_rounded_number in $(printf %.0f $floating_point_number); do echo "Rounded number with bash:" $bash_rounded_number done
17.4. Bash floating point calculations
#!/bin/bash # Simple linux bash calculator echo "Enter input:" read userinput echo "Result with 2 digits after decimal point:" echo "scale=2; $" | bc echo "Result with 10 digits after decimal point:" echo "scale=10; $" | bc echo "Result as rounded integer:" echo $userinput | bc
18. Redirections
18.1. STDOUT from bash script to STDERR
#!/bin/bash echo "Redirect this STDOUT to STDERR" 1>&2
To proof that STDOUT is redirected to STDERR we can redirect script's output to file:

18.2. STDERR from bash script to STDOUT
#!/bin/bash cat $1 2>&1
To proof that STDERR is redirected to STDOUT we can redirect script's output to file:

18.3. stdout to screen
The simple way to redirect a standard output ( stdout ) is to simply use any command, because by default stdout is automatically redirected to screen.
cat /proc/partitions
18.4. stdout to file
Here we use ">" to redirect stdout to a file "partitions.txt".
cat /proc/partitions > partitions.txt
18.5. stderr to file
In this example you will redirect the standard error ( stderr ) to a file and stdout to a default screen.
grep -r hda6 * . 2> stderr.txt
18.6. stdout to stderr
In this case the output of a command will be written to the same descriptor as a stderr.
grep -r hda6 * . 1>&2 stderr.txt
18.7. stderr to stdout
In this case the stderr of a command will be written to the same descriptor as a stdout.
grep -r hda6 * . 2>&1 stderr.txt
18.8. stderr and stdout to file
grep -r hda6 * . &> stderr_and_stdout.txt
Configure for high load Linux system
Suggest kernel parameters:
sysctl -w fs.file-max=360000
net.ipv4.ip_local_port_range="1024 65000"
kernel.shmall = 2097152
kernel.shmmax = 2147483648
kernel.shmmni = 4096
kernel.sem = 250 32000 100 128
fs.file-max = 65536
net.ipv4.ip_local_port_range = 1024 65000
net.core.rmem_default = 1048576
net.core.rmem_max = 1048576
net.core.wmem_default = 262144
net.core.wmem_max = 262144
****************************************************************************************************************
**//10GB NIC
****************************************************************************************************************
# increase TCP max buffer size setable using setsockopt()
# 16 MB with a few parallel streams is recommended for most 10G paths
# 32 MB might be needed for some very long end-to-end 10G or 40G paths
net.core.rmem_max = 16777216
net.core.wmem_max = 16777216
# increase Linux autotuning TCP buffer limits
# min, default, and max number of bytes to use
# (only change the 3rd value, and make it 16 MB or more)
net.ipv4.tcp_rmem = 4096 87380 16777216
net.ipv4.tcp_wmem = 4096 65536 16777216
# recommended to increase this for 10G NICS
net.core.netdev_max_backlog = 30000
****************************************************************************************************************
To change this, you have to edit the file /etc/security/limits.conf as root and make the following changes or add the following lines, respectively:
# To increase the shell limits for <user>
<user> soft nproc 2047
<user> hard nproc 16384
<user> soft nofile 1024
<user> hard nofile 65536
The «soft limit» in the first line defines the number of file handles or open files that the user will have after login. If the user gets error messages about running out of file handles, then the user can increase the number of file handles like in this example up to 63536 («hard limit») by running the following command:
ulimit -n 63536
Note that we do not recommend to set the «hard limit» for nofile for the user equal to/proc/sys/fs/file-max. If you do that and the user uses up all the file handles, then the system would run out of file handles. This could mean that you won't be able to initiate new remote logins any more since the system won't be able to open any PAM modules which are required for performing a login. That's why we set the hard limit to 63536 and not to 65536.
You also need to make sure that pam_limits is configured in the file /etc/pam.d/system-auth. This is the PAM module that will read the /etc/security/limits.conf file. The entry should read like:
session required pam_limits.so
session required pam_unix.so
sysctl -w fs.file-max=360000
net.ipv4.ip_local_port_range="1024 65000"
kernel.shmall = 2097152
kernel.shmmax = 2147483648
kernel.shmmni = 4096
kernel.sem = 250 32000 100 128
fs.file-max = 65536
net.ipv4.ip_local_port_range = 1024 65000
net.core.rmem_default = 1048576
net.core.rmem_max = 1048576
net.core.wmem_default = 262144
net.core.wmem_max = 262144
****************************************************************************************************************
**//10GB NIC
****************************************************************************************************************
# increase TCP max buffer size setable using setsockopt()
# 16 MB with a few parallel streams is recommended for most 10G paths
# 32 MB might be needed for some very long end-to-end 10G or 40G paths
net.core.rmem_max = 16777216
net.core.wmem_max = 16777216
# increase Linux autotuning TCP buffer limits
# min, default, and max number of bytes to use
# (only change the 3rd value, and make it 16 MB or more)
net.ipv4.tcp_rmem = 4096 87380 16777216
net.ipv4.tcp_wmem = 4096 65536 16777216
# recommended to increase this for 10G NICS
net.core.netdev_max_backlog = 30000
****************************************************************************************************************
To change this, you have to edit the file /etc/security/limits.conf as root and make the following changes or add the following lines, respectively:
# To increase the shell limits for <user>
<user> soft nproc 2047
<user> hard nproc 16384
<user> soft nofile 1024
<user> hard nofile 65536
The «soft limit» in the first line defines the number of file handles or open files that the user will have after login. If the user gets error messages about running out of file handles, then the user can increase the number of file handles like in this example up to 63536 («hard limit») by running the following command:
ulimit -n 63536
Note that we do not recommend to set the «hard limit» for nofile for the user equal to/proc/sys/fs/file-max. If you do that and the user uses up all the file handles, then the system would run out of file handles. This could mean that you won't be able to initiate new remote logins any more since the system won't be able to open any PAM modules which are required for performing a login. That's why we set the hard limit to 63536 and not to 65536.
You also need to make sure that pam_limits is configured in the file /etc/pam.d/system-auth. This is the PAM module that will read the /etc/security/limits.conf file. The entry should read like:
session required pam_limits.so
session required pam_unix.so
Asterisk + FreePBX Installations (CentOS)
yum install gcc gcc-c++ wget bison mysql-devel mysql-server php php-mysql php-pear php-pear-DB php-mbstring nano ntp tftp-server httpd make ncurses-devel libtermcap-devel sendmail sendmail-cf caching-nameserver sox newt-devel libxml2-devel libtiff-devel php-gd audiofile-devel gtk2-devel
Ensure Hard Drive SMART monitoring is enabled (if using SATA hardware RAID then disable) chkconfig smartd on Configure the network time server for managing the time displayed on the server and the phones. nano +21 /etc/ntp.conf restrict 192.168.1.0 mask 255.255.255.0 nomodify notrap server 0.rhel.pool.ntp.org server 1.rhel.pool.ntp.org server 2.rhel.pool.ntp.org Leave everything else at defaults. Any other lines that start with “restrict” should be commented out “#” Configure time server to start at boot /sbin/chkconfig --level 345 ntpd on cd /usr/src wget http://easynews.dl.sourceforge.net/sourceforge/lame/lame-3.97.tar.gz tar zxvf lame-3.97.tar.gz cd lame-3.97 ./configure make make install cd /usr/src wget http://mirror.freepbx.org/freepbx-2.8.0.tar.gz tar zxvf freepbx-2.8.0.tar.gz wget http://downloads.asterisk.org/pub/telephony/asterisk/releases/asterisk-1.6.2.13.tar.gz tar zxvf asterisk-1.6.2.13.tar.gz wget http://downloads.asterisk.org/pub/telephony/asterisk/releases/asterisk-addons-1.6.2.2.tar.gz tar zxvf asterisk-addons-1.6.2.2.tar.gz wget http://downloads.asterisk.org/pub/telephony/dahdi-linux-complete/releases/dahdi-linux-complete-2.4.0+2.4.0.tar.gz tar zxvf dahdi-linux-complete-2.4.0+2.4.0.tar.gz wget http://downloads.asterisk.org/pub/telephony/libpri/libpri-1.4.11.5.tar.gz tar zxvf libpri-1.4.11.5.tar.gz mkdir /var/lib/asterisk mkdir /var/lib/asterisk/sounds cd /var/lib/asterisk/sounds wget http://downloads.digium.com/pub/telephony/sounds/asterisk-extra-sounds-en-gsm-current.tar.gz tar zxvf asterisk-extra-sounds-en-gsm-current.tar.gz cd /usr/src/dahdi-linux-complete-2.4.0+2.4.0 make clean && make all && make install && make config cd /usr/src/libpri-1.4.11.5 make clean && make && make install cd /usr/src/asterisk-1.6.2.13 make clean && ./configure && make menuselect make && make install mkdir /var/run/asterisk cd /usr/src wget http://sourceforge.net/projects/mpg123/files/mpg123/1.12.5/mpg123-1.12.5.tar.bz2/download tar -xjvf mpg123-1.12.5.tar.bz2 ./configure make make install ln -s /usr/local/bin/mpg123 /usr/bin/mpg123 cd /usr/src/freepbx-2.8.0 useradd -c "Asterisk PBX" -d /var/lib/asterisk asterisk chown -R asterisk /var/run/asterisk chown -R asterisk /var/log/asterisk chown -R asterisk /var/lib/asterisk/moh chown -R asterisk /var/lib/php/session chkconfig httpd on chkconfig mysqld on service mysqld start cd /usr/src/freepbx-2.8.0mysqladmin create asteriskmysqladmin create asteriskcdrdbmysql asterisk < SQL/newinstall.sqlmysql asteriskcdrdb < SQL/cdr_mysql_table.sql #set mysql passwordGRANT ALL PRIVILEGES ON asteriskcdrdb.* TO asteriskuser@localhost IDENTIFIED BY '<password'; GRANT ALL PRIVILEGES ON asterisk.* TO asteriskuser@localhost IDENTIFIED BY '<password>';flush privileges; cd /usr/src/asterisk-addons-1.6.2.2make clean && ./configure && make menuselectmake && make install /usr/sbin/safe_asteriskcd /usr/src/freepbx-2.8.0./install_amp echo /usr/local/sbin/amportal start >> /etc/rc.local #Edit /etc/asterisk/cdr_mysql.conf and add 'loguniqueid=yes' to the global section nano /etc/asterisk/cdr_mysql.conf loguniqueid=yes #To change the password for administrator "recordings" GUI (access to extension voicemail, call monitoring, #recording etc.) nano -w /var/www/html/recordings/includes/main.conf.php $ARI_ADMIN_PASSWORD ="password" nano +582 /etc/php.ini#change the “max filesize” from 2M to 20M to allow larger music on hold files source ref : http://www.powerpbx.org/content/my-hardware-centos-v5x-asterisk-v16x-freepbx-v24x |
Showing: 1-1 of 1
Comments
| 07 Mar, 2011 | chungyl |
Sample of chan_dahdi.conf
========================== [channels] language=en ; XTDM20B Port #1,2 plugged into PSTN ;AMPLABEL:Channel %c - Button %n usecallerid=yes hidecallerid=no callwaiting=yes threewaycalling=yes tran sfer=yes echocancel=yes echocancelwhenbridged=yes rxgain=0.0 txgain=0.0 bus ydetect=yes callprogress=no ;FXO Modules group=0 signalling=fxs_ks context=from-dahdi channel=1-2 ;FXS Modules group=1 echocancel=yes signalling=fxo_ks context=from-internal chan nel=3-4 #include chan_dahdi_additional.conf |
Subscribe to:
Posts (Atom)